==> haskell-mockery-0.3.5-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-AnLTOOFqO3k7SI8NC8IKwj
key:                  mockery-0.3.5-AnLTOOFqO3k7SI8NC8IKwj
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  1be14c54fbc12a328409b13c53327de5
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-8.10.1/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/mockery-0.3.5
hs-libraries:         HSmockery-0.3.5-AnLTOOFqO3k7SI8NC8IKwj
depends:
    base-4.14.0.0 base-compat-0.11.1-KZnxD44j0rC2RthL96Vmwl
    bytestring-0.10.10.0 directory-1.3.6.0 filepath-1.4.2.1
    logging-facade-0.3.0-6nEEfukaZKKISWvjCkHguM
    temporary-1.3-FPmHKIJnX7EI2FnOsQxefl

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-75ea9fQvMZ125MLTE7Gbko
key:                  mockery-0.3.5-75ea9fQvMZ125MLTE7Gbko
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  5129565bce93ff143b79415fcd9448df
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-8.10.1/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/mockery-0.3.5
hs-libraries:         HSmockery-0.3.5-75ea9fQvMZ125MLTE7Gbko
depends:
    base-4.14.0.0 base-compat-0.11.1-KZnxD44j0rC2RthL96Vmwl
    bytestring-0.10.10.0 directory-1.3.6.0 filepath-1.4.2.1
    logging-facade-0.3.0-5MU7tEoiyba34Egb8jzC4
    temporary-1.3-LeRCerT2C7kEhJJDBRA3NZ

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
